@@ -2,6 +2,7 @@ import logging
 from typing import Annotated, Any
 
 from pydantic import BeforeValidator, Field, PlainSerializer, ValidationInfo
+from pydantic.fields import FieldInfo
 
 from unique_toolkit.language_model import LanguageModelName
 from unique_toolkit.language_model.infos import (
@@ -9,9 +10,6 @@ from unique_toolkit.language_model.infos import (
     LanguageModelProvider,
 )
 
-from pydantic.fields import FieldInfo
-
-
 logger = logging.getLogger(__name__)
 
 # TODO @klcd: Inform on deprecation of str as input
@@ -29,6 +27,14 @@ LMI = Annotated[
 ]
 
 
+def get_LMI_default_field(llm_name: LanguageModelName, **kwargs) -> Any:
+    return Field(
+        default=LanguageModelInfo.from_name(llm_name),
+        json_schema_extra={"default": llm_name},
+        **kwargs,
+    )
+
+
 def serialize_lmi(model: LanguageModelInfo) -> str | LanguageModelInfo:
     if model.provider == LanguageModelProvider.CUSTOM:
         return model
